[![License](https://img.shields.io/pypi/l/myp)](https://github.com/yunisdev/myp/blob/master/LICENSE.txt) 
[![Documentation Status](https://readthedocs.org/projects/myp/badge/?version=latest)](myp.readthedocs.io/en/latest/?badge=latest) 
[![Upload Python Package](https://github.com/yunisdev/myp/actions/workflows/python-publish.yml/badge.svg)](https://github.com/yunisdev/myp/actions/workflows/python-publish.yml)
[![Pylint](https://github.com/yunisdev/myp/actions/workflows/pylint.yml/badge.svg)](https://github.com/yunisdev/myp/actions/workflows/pylint.yml) 
[![Pypi](https://img.shields.io/pypi/v/myp?logo=python&logoColor=white)](https://pypi.org/project/myp/) 
![Size](https://img.shields.io/github/repo-size/yunisdev/myp?logo=github)
![Stars](https://img.shields.io/github/stars/yunisdev/myp?logo=github)
# <img height="24" width="24" src="https://raw.githubusercontent.com/YunisDEV/myp/master/docs/myp_icon.svg"/> ManageYourPython

## What is MYP?
**myp** is a tool that helps you to manage and develop your Python apps easily.

## Learn more about MYP

Full documentation is available at languages below:

- [English](https://myp.readthedocs.io/en/latest)
- [Azərbaycan dili](https://myp.readthedocs.io/az/latest)